#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-silver
version:              3.3.2.1
visibility:           public
id:                   tasty-silver-3.3.2.1-4oFiUhhao3T6qYtHV9wv0c
key:                  tasty-silver-3.3.2.1-4oFiUhhao3T6qYtHV9wv0c
license:              MIT
maintainer:           Andreas Abel, Philipp Hausmann
author:               Philipp Hausmann, Andreas Abel, Roman Cheplyaka, and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  f43a72ee42f078787a9eb5b958039812
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-silver-3.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-silver-3.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-silver-3.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.2.1-4oFiUhhao3T6qYtHV9wv0c
depends:
    ansi-terminal-1.1-CupeHe6p1cfEgQRMak7it6 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-64q3Zt8gfMnAm6zpFRaIVN
    process-1.6.19.0 process-extras-0.7.4-5wl1D3cYe3y3T5hW4P3kj6
    regex-tdfa-1.3.2.5-7pJaUTnbPYM9Za1KnP0Rwp
    silently-1.2.5.4-BeJQMFrht8zIosElyGUCP7 stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-DzOELAxGOkcCrvV9YMidRG
    temporary-1.3-AzCvydY1Gof51L3aNIQbtm text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

